public inbox for igt-dev@lists.freedesktop.org
 help / color / mirror / Atom feed
From: "Michał Grzelak" <michal.grzelak@intel.com>
To: igt-dev@lists.freedesktop.org
Cc: mohammed.thasleem@intel.com, "Michał Grzelak" <michal.grzelak@intel.com>
Subject: [PATCH i-g-t 1/6] tests/kms_flip: test suspend on one pair of pipes
Date: Tue, 24 Feb 2026 14:32:37 +0100	[thread overview]
Message-ID: <20260224133242.1678232-2-michal.grzelak@intel.com> (raw)
In-Reply-To: <20260224133242.1678232-1-michal.grzelak@intel.com>

Currently, every pair of ({pipe1, pipe2}, {output1, output2}) is being
tested in 2x-* subtests. Since suspend shouldn't be tested per pipe, it
causes unnecessary overhead: with 4 pipes & 4 displays it runs up to 36
tests. Given that each suspend's dynamic subtest can take up to tens of
seconds, total duration of the test easily exceeds timeout.

When testing suspend, for each pair of outputs test only first and last
pipe unless it is said to run on all pipes.

Signed-off-by: Michał Grzelak <michal.grzelak@intel.com>
---
 tests/kms_flip.c | 10 ++++++++--
 1 file changed, 8 insertions(+), 2 deletions(-)

diff --git a/tests/kms_flip.c b/tests/kms_flip.c
index 49a5f4ed1..8bda82627 100755
--- a/tests/kms_flip.c
+++ b/tests/kms_flip.c
@@ -1918,6 +1918,12 @@ static void run_pair(int duration, int flags)
 		for (n = 0; n < resources->count_crtcs; n++) {
 			for (j = i + 1; j < resources->count_connectors; j++) {
 				for (m = n + 1; m < resources->count_crtcs; m++) {
+					/* Limit the execution to 2 CRTCs (first & last) for hang and suspend tests */
+					if (((flags & TEST_HANG) || (flags & TEST_SUSPEND)) && !all_crtcs &&
+					    ((n != 0 && n != resources->count_crtcs) ||
+					    m != resources->count_crtcs - 1))
+						continue;
+
 					memset(&o, 0, sizeof(o));
 					o.count = 2;
 					o._connector[0] = resources->connectors[i];
@@ -1963,8 +1969,8 @@ static void run_pair(int duration, int flags)
 					crtc_idxs[0] = n;
 					crtc_idxs[1] = m;
 
-					/* Limit the execution to 2 CRTCs (first & last) for hang tests */
-					if ((flags & TEST_HANG) && !all_crtcs &&
+					/* Limit the execution to 2 CRTCs (first & last) for hang and suspend tests */
+					if (((flags & TEST_HANG) || (flags & TEST_SUSPEND)) && !all_crtcs &&
 					    ((n != 0 && n != resources->count_crtcs) ||
 					    m != resources->count_crtcs - 1))
 						continue;
-- 
2.45.2


  reply	other threads:[~2026-02-24 13:32 UTC|newest]

Thread overview: 11+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-02-24 13:32 [PATCH i-g-t v6 0/6] kms_flip: limit number of subtests run Michał Grzelak
2026-02-24 13:32 ` Michał Grzelak [this message]
2026-02-24 13:32 ` [PATCH i-g-t 2/6] tests/kms_flip: run suspend tests on one pipe per output Michał Grzelak
2026-02-24 13:32 ` [PATCH i-g-t 3/6] tests/kms_flip: limit output pairs when testing suspend Michał Grzelak
2026-02-24 13:32 ` [PATCH i-g-t 4/6] tests/kms_flip: limit number of outputs wrt suspend Michał Grzelak
2026-02-24 13:32 ` [PATCH i-g-t 5/6] tests/kms_flip: initialize global devid Michał Grzelak
2026-02-24 14:21   ` Jani Nikula
2026-02-24 13:32 ` [PATCH i-g-t 6/6] tests/kms_flip: test suspend at most twice on SNB Michał Grzelak
2026-02-24 15:08 ` ✓ Xe.CI.BAT: success for kms_flip: limit number of subtests run (rev6) Patchwork
2026-02-24 15:46 ` ✗ i915.CI.BAT: failure " Patchwork
2026-02-25  1:25 ` ✗ Xe.CI.FULL: " Patchwork

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260224133242.1678232-2-michal.grzelak@intel.com \
    --to=michal.grzelak@intel.com \
    --cc=igt-dev@lists.freedesktop.org \
    --cc=mohammed.thasleem@intel.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox